window.onload = function () {

	var clock, mixer, camera, scene, renderer, model;

	var init = function () {

		clock = new THREE.Clock();

		scene = new THREE.Scene();
		camera = new THREE.PerspectiveCamera( 25, window.innerWidth / window.innerHeight, 0.01, 10 );
		camera.position.set( 0, 0.05, 0.4 );

		renderer = new THREE.WebGLRenderer( {
			antialias: true,
			alpha: true
		} );

		renderer.setPixelRatio( window.devicePixelRatio );
		renderer.setSize( window.innerWidth, window.innerHeight );
		renderer.shadowMap.enabled = true;
		renderer.outputEncoding = THREE.sRGBEncoding;
		document.body.append( renderer.domElement );

		window.addEventListener( 'resize', () => {

			renderer.setSize( window.innerWidth, window.innerHeight );
			camera.aspect = window.innerWidth / window.innerHeight;
			camera.updateProjectionMatrix();

		} );

		var controls = new THREE.OrbitControls( camera, renderer.domElement );

		var GLBFile = 'hero.glb';

		var loader = new THREE.GLTFLoader();
		loader.load( GLBFile, async ( gltf ) => {

			model = gltf.scene;
			gltf.scene.traverse( function ( node ) {

				if ( node.isMesh ) {

					node.castShadow = true;
					node.receiveShadow = true;
					node.material.metalness = 0; // undo this change if you apply an env map

				}

			} );

			mixer = new THREE.AnimationMixer( gltf.scene );
			var action = mixer.clipAction( gltf.animations[ 0 ] );
			action.play();
			scene.add( model );
			animate();

		},
		function ( xhr ) {

			console.log( ( xhr.loaded / xhr.total * 100 ) + '% loaded' );

		},
		function ( error ) {

			console.error( 'An error happened', error );

		} );

		// lights

		var hemiLight = new THREE.HemisphereLight( 0xffffff, 0x444444 );
		hemiLight.position.set( 0, 1, 0 );
		scene.add( hemiLight );

		var dirLight = new THREE.DirectionalLight( 0xffffff, 0.8 );
		dirLight.position.set( 0, 1, 1 );
		dirLight.castShadow = true;
		dirLight.shadow.camera.top = 0.2;
		dirLight.shadow.camera.bottom = - 0.2;
		dirLight.shadow.camera.left = - 0.2;
		dirLight.shadow.camera.right = 0.2;
		dirLight.shadow.camera.near = 0.1;
		dirLight.shadow.camera.far = 2;
		dirLight.shadow.mapSize.set( 1024, 1024 );
		scene.add( dirLight );

		scene.add( new THREE.CameraHelper( dirLight.shadow.camera ) );

		var mesh = new THREE.Mesh( new THREE.PlaneBufferGeometry( 100, 100 ), new THREE.MeshPhongMaterial( { color: 0x999999, depthWrite: false } ) );
		mesh.rotation.x = - Math.PI / 2;
		mesh.receiveShadow = true;
		mesh.castShadow = true;
		scene.add( mesh );


		function animate() {

			requestAnimationFrame( animate );
			var delta = clock.getDelta();
			if ( mixer ) mixer.update( delta );
			render();

		}

		function render() {

			renderer.render( scene, camera );

		}

	};

	init();

};
